@@ -11,6 +11,7 @@
 #include <dune/common/parallel/mpihelper.hh>
 #include <dune/common/fvector.hh>
 #include <dune/common/typetraits.hh>
+#include <dune/common/std/make_array.hh>
 #include <dune/grid/yaspgrid.hh>
 #include <dune/grid/utility/structuredgridfactory.hh>
 #include <dune/pdelab/gridfunctionspace/gridfunctionspace.hh>
@@ -50,7 +51,7 @@ void test_2d_cube(const Constraints& constraints, const VBE& vbe)
 
   // make grid
   Dune::FieldVector<double,2> L(1.0);
-  Dune::array<int,2> N;
+  std::array<int,2> N;
   std::fill(N.begin(),N.end(),1);
   Dune::YaspGrid<2> grid(L,N);
   grid.globalRefine(3);
@@ -76,7 +77,7 @@ void test_3d_cube(const Constraints& constraints, const VBE& vbe)
 
   // make grid
   Dune::FieldVector<double,3> L(1.0);
-  Dune::array<int,3> N;
+  std::array<int,3> N;
   std::fill(N.begin(),N.end(),1);
 
   Dune::YaspGrid<3> grid(L,N);
@@ -106,7 +107,7 @@ void test_2d_simplex(const Constraints& constraints, const VBE& vbe)
     {
       // make grid
       using ALUType = Dune::ALUGrid<2, 2, Dune::simplex, Dune::nonconforming>;
-      auto alugrid = Dune::StructuredGridFactory<ALUType>::createSimplexGrid(Dune::FieldVector<ALUType::ctype, 2>(0.0), Dune::FieldVector<ALUType::ctype, 2>(1.0), Dune::make_array(1u, 1u));
+      auto alugrid = Dune::StructuredGridFactory<ALUType>::createSimplexGrid(Dune::FieldVector<ALUType::ctype, 2>(0.0), Dune::FieldVector<ALUType::ctype, 2>(1.0), Dune::Std::make_array(1u, 1u));
       alugrid->globalRefine(3);
 
       // get view
@@ -162,7 +163,7 @@ void test_3d_simplex(const Constraints& constraints, const VBE& vbe)
 
     {
       using ALUType = Dune::ALUGrid<3, 3, Dune::simplex, Dune::nonconforming>;
-      auto alugrid = Dune::StructuredGridFactory<ALUType>::createSimplexGrid(Dune::FieldVector<ALUType::ctype, 3>(0.0), Dune::FieldVector<ALUType::ctype, 3>(1.0), Dune::make_array(1u, 1u, 1u));
+      auto alugrid = Dune::StructuredGridFactory<ALUType>::createSimplexGrid(Dune::FieldVector<ALUType::ctype, 3>(0.0), Dune::FieldVector<ALUType::ctype, 3>(1.0), Dune::Std::make_array(1u, 1u, 1u));
       alugrid->globalRefine(3);
 
       // get view
@@ -219,7 +220,7 @@ int main(int argc, char** argv)
     typedef Dune::PDELab::NoConstraints Constraints;
     Constraints constraints DUNE_UNUSED;
 
-    typedef Dune::PDELab::istl::VectorBackend<> VBE;
+    typedef Dune::PDELab::ISTL::VectorBackend<> VBE;
     VBE vbe DUNE_UNUSED;
 
     typedef double RF DUNE_UNUSED;
