@@ -13,6 +13,7 @@
 
 #include<dune/common/parallel/mpihelper.hh>
 #include<dune/common/exceptions.hh>
+#include<dune/common/filledarray.hh>
 #include<dune/common/fvector.hh>
 #include<dune/common/typetraits.hh>
 #include<dune/common/timer.hh>
@@ -179,12 +180,11 @@ void stationary (const GV& gv)
   const int dim = GV::dimension;
 
   // <<<2>>> Make grid function space
-  Dune::GeometryType gt;
-  gt.makeCube(dim);
+  auto gt = Dune::GeometryTypes::cube(dim);
   typedef Dune::PDELab::P0LocalFiniteElementMap<Coord,Real,dim> FEM;
   FEM fem(gt); // works only for cubes
   typedef Dune::PDELab::P0ParallelConstraints CON;
-  typedef Dune::PDELab::istl::VectorBackend<> VBE;
+  typedef Dune::PDELab::ISTL::VectorBackend<> VBE;
   typedef Dune::PDELab::GridFunctionSpace<GV,FEM,CON,VBE> GFS;
   GFS gfs(gv,fem);
 
@@ -206,7 +206,7 @@ void stationary (const GV& gv)
   // <<<4>>> Make grid operator
   typedef Dune::PDELab::ConvectionDiffusionCCFV<Param> LOP;
   LOP lop(param);
-  typedef Dune::PDELab::istl::BCRSMatrixBackend<> MBE;
+  typedef Dune::PDELab::ISTL::BCRSMatrixBackend<> MBE;
   MBE mbe(5); // Maximal number of nonzeroes per row can be cross-checked by patternStatistics().
   typedef Dune::PDELab::GridOperator<GFS,GFS,LOP,MBE,Real,Real,Real,CC,CC> GO;
   GO go(gfs,cc,gfs,cc,lop,mbe);
@@ -254,12 +254,11 @@ void implicit_scheme (const GV& gv, double Tend, double timestep)
   const int dim = GV::dimension;
 
   // <<<2>>> Make grid function space
-  Dune::GeometryType gt;
-  gt.makeCube(dim);
+  auto gt = Dune::GeometryTypes::cube(dim);
   typedef Dune::PDELab::P0LocalFiniteElementMap<Coord,Real,dim> FEM;
   FEM fem(gt); // works only for cubes
   typedef Dune::PDELab::P0ParallelConstraints CON;
-  typedef Dune::PDELab::istl::VectorBackend<> VBE;
+  typedef Dune::PDELab::ISTL::VectorBackend<> VBE;
   typedef Dune::PDELab::GridFunctionSpace<GV,FEM,CON,VBE> GFS;
   GFS gfs(gv,fem);
 
@@ -283,7 +282,7 @@ void implicit_scheme (const GV& gv, double Tend, double timestep)
   LOP lop(param);
   typedef Dune::PDELab::ConvectionDiffusionCCFVTemporalOperator<Param> SLOP;
   SLOP slop(param);
-  typedef Dune::PDELab::istl::BCRSMatrixBackend<> MBE;
+  typedef Dune::PDELab::ISTL::BCRSMatrixBackend<> MBE;
   MBE mbe(5); // number of nonzero entries per row can be cross-checked by patternStatistics().
   Dune::PDELab::FractionalStepParameter<Real> method;
   typedef Dune::PDELab::GridOperator<GFS,GFS,LOP,MBE,Real,Real,Real,CC,CC> GO0;
@@ -355,12 +354,11 @@ void explicit_scheme (const GV& gv, double Tend, double timestep)
   const int dim = GV::dimension;
 
   // <<<2>>> Make grid function space
-  Dune::GeometryType gt;
-  gt.makeCube(dim);
+  auto gt = Dune::GeometryTypes::cube(dim);
   typedef Dune::PDELab::P0LocalFiniteElementMap<Coord,Real,dim> FEM;
   FEM fem(gt); // works only for cubes
   typedef Dune::PDELab::P0ParallelConstraints CON;
-  typedef Dune::PDELab::istl::VectorBackend<> VBE;
+  typedef Dune::PDELab::ISTL::VectorBackend<> VBE;
   typedef Dune::PDELab::GridFunctionSpace<GV,FEM,CON,VBE> GFS;
   GFS gfs(gv,fem);
 
@@ -384,7 +382,7 @@ void explicit_scheme (const GV& gv, double Tend, double timestep)
   LOP lop(param);
   typedef Dune::PDELab::ConvectionDiffusionCCFVTemporalOperator<Param> SLOP;
   SLOP slop(param);
-  typedef Dune::PDELab::istl::BCRSMatrixBackend<> MBE;
+  typedef Dune::PDELab::ISTL::BCRSMatrixBackend<> MBE;
   MBE mbe(5); // number of nonzero entries per row can be cross-checked by patternStatistics().
   typedef Dune::PDELab::GridOperator<GFS,GFS,LOP,MBE,Real,Real,Real,CC,CC> GO0;
   GO0 go0(gfs,cc,gfs,cc,lop,mbe);
@@ -496,7 +494,7 @@ int main(int argc, char** argv)
     if (true) {
       const int dim = 2;
       Dune::FieldVector<double,dim> L(1.0);
-      Dune::array<int,dim> N(Dune::fill_array<int,dim>(n));
+      std::array<int,dim> N(Dune::filledArray<dim, int>(n));
       std::bitset<dim> periodic(false);
       int overlap=o;
       Dune::YaspGrid<dim> grid(L,N,periodic,overlap,helper.getCommunicator());
