@@ -8,6 +8,7 @@
 #include <iostream>
 #include <string>
 
+#include <dune/common/filledarray.hh>
 #include <dune/common/parallel/mpihelper.hh>
 #include <dune/grid/yaspgrid.hh>
 #include <dune/istl/solvers.hh>
@@ -24,6 +25,7 @@
 #include <dune/pdelab/gridoperator/gridoperator.hh>
 #include <dune/pdelab/localoperator/convectiondiffusionfem.hh>
 #include <dune/pdelab/gridfunctionspace/vtk.hh>
+#include <dune/pdelab/stationary/linearproblem.hh>
 
 #include "gridexamples.hh"
 
@@ -140,8 +142,6 @@ public:
 template<typename GV, typename FEM, typename CON>
 void poisson (const GV& gv, const FEM& fem, std::string filename, int q)
 {
-  typedef Dune::PDELab::EigenMatrixBackend<> MBE;
-
   // constants and types
   typedef typename FEM::Traits::FiniteElementType::Traits::
     LocalBasisType::Traits::RangeFieldType R;
@@ -151,7 +151,7 @@ void poisson (const GV& gv, const FEM& fem, std::string filename, int q)
     GV,
     FEM,
     CON,
-    Dune::PDELab::EigenVectorBackend
+    Dune::PDELab::Eigen::VectorBackend
     > GFS;
   GFS gfs(gv,fem);
   gfs.name("solution");
@@ -171,12 +171,19 @@ void poisson (const GV& gv, const FEM& fem, std::string filename, int q)
   typedef Dune::PDELab::ConvectionDiffusionFEM<Problem,FEM> LOP;
   LOP lop(problem);
 
+  // matrix backend
+  typedef Dune::PDELab::Eigen::MatrixBackend<> MBE;
+  int avgnz = 27;
+  MBE mbe(avgnz);
+
   // make grid operator
   typedef Dune::PDELab::GridOperator<GFS,GFS,LOP,
                                      MBE,
                                      double,double,double,
                                      C,C> GridOperator;
-  GridOperator gridoperator(gfs,cg,gfs,cg,lop);
+  GridOperator gridoperator(gfs,cg,gfs,cg,lop,mbe);
+
+  Dune::Timer timer;
 
   // make coefficent Vector and initialize it from a function
   // There is some weird shuffling around here - please leave it in,
@@ -205,7 +212,7 @@ void poisson (const GV& gv, const FEM& fem, std::string filename, int q)
   typedef typename GridOperator::Traits::Jacobian M;
   M m;
   {
-    M m1(gridoperator, 27);
+    M m1(gridoperator);
     M m2(m1);
     m2 = 0.0;
     m = m1;
@@ -223,7 +230,6 @@ void poisson (const GV& gv, const FEM& fem, std::string filename, int q)
   r = 0.0;
   gridoperator.residual(x0,r);
 
-  DV x(gfs,0.0);
   // test the container interface
   {
     // make ISTL solver
@@ -232,14 +238,33 @@ void poisson (const GV& gv, const FEM& fem, std::string filename, int q)
     Dune::Richardson<DV,RV> richardson(1.0);
   }
 
+  DV x(gfs,0.0);
+
   // test the solver backend
   {
+    M m(gridoperator);
     // make EIGEN solver
     Dune::PDELab::EigenBackend_BiCGSTAB_Diagonal solver;
+    x = 0.0;
+    gridoperator.jacobian(x0,m);
     // solve the jacobian system
     r *= -1.0; // need -residual
     solver.apply(m,x,r,1e-10);
     x += x0;
+    std::cout << "Time manually: " << timer.elapsed() << std::endl;
+  }
+
+  // test the solver backend as part of a pdelab solver
+  {
+    Dune::Timer timer;
+    std::cout << "StationaryLinearProblemSolver" << std::endl;
+    typedef Dune::PDELab::EigenBackend_BiCGSTAB_Diagonal LS;
+    LS linearSolver(5000);
+    x = 0.0;
+    Dune::PDELab::StationaryLinearProblemSolver<GridOperator,LS,DV> slp(gridoperator,linearSolver,x,1e-10);
+    slp.apply();
+    x += x0;
+    std::cout << "Time SLPSolver: " << timer.elapsed() << std::endl;
   }
 
   // output grid function with VTKWriter
@@ -262,9 +287,9 @@ int main(int argc, char** argv)
     {
       // make grid
       Dune::FieldVector<double,2> L(1.0);
-      Dune::array<int,2> N(Dune::fill_array<int,2>(1));
+      std::array<int,2> N(Dune::filledArray<2,int>(1));
       Dune::YaspGrid<2> grid(L,N);
-      grid.globalRefine(3);
+      grid.globalRefine(5);
 
       // get view
       typedef Dune::YaspGrid<2>::LeafGridView GV;
@@ -283,9 +308,9 @@ int main(int argc, char** argv)
     {
       // make grid
       Dune::FieldVector<double,2> L(1.0);
-      Dune::array<int,2> N(Dune::fill_array<int,2>(1));
+      std::array<int,2> N(Dune::filledArray<2,int>(1));
       Dune::YaspGrid<2> grid(L,N);
-      grid.globalRefine(3);
+      grid.globalRefine(5);
 
       // get view
       typedef Dune::YaspGrid<2>::LeafGridView GV;
