@@ -6,6 +6,7 @@
 #include <vector>
 #include <map>
 
+#include <dune/common/filledarray.hh>
 #include <dune/common/parallel/mpihelper.hh>
 #include <dune/grid/yaspgrid.hh>
 
@@ -124,7 +125,7 @@ void testp1 (const GV& gv, double mu, double lambda, double constG)
 
   // make function space
   typedef Dune::PDELab::ConformingDirichletConstraints Constraints;
-  typedef Dune::PDELab::istl::VectorBackend<> ComponentVectorBackend;
+  typedef Dune::PDELab::ISTL::VectorBackend<> ComponentVectorBackend;
 
   typedef Dune::PDELab::DefaultLeafOrderingTag Mapper;
 
@@ -133,7 +134,7 @@ void testp1 (const GV& gv, double mu, double lambda, double constG)
     GV,
     FEM,
     dim,
-    Dune::PDELab::istl::VectorBackend<>,
+    Dune::PDELab::ISTL::VectorBackend<>,
     ComponentVectorBackend,
     Constraints,
     OrderingTag,
@@ -160,7 +161,7 @@ void testp1 (const GV& gv, double mu, double lambda, double constG)
   typedef Dune::PDELab::LinearElasticity<Param> LO;
   LO lo(param);
 
-  typedef Dune::PDELab::istl::BCRSMatrixBackend<> MBE;
+  typedef Dune::PDELab::ISTL::BCRSMatrixBackend<> MBE;
   MBE mbe(9); // 2D Q1
 
   // make grid operator
@@ -194,8 +195,8 @@ void testp1 (const GV& gv, double mu, double lambda, double constG)
   gos.residual(x0,r);
 
   // make ISTL solver
-  typedef typename M::BaseT ISTL_M;
-  typedef typename V::BaseT ISTL_V;
+  typedef typename M::Container ISTL_M;
+  typedef typename V::Container ISTL_V;
   Dune::MatrixAdapter<ISTL_M,ISTL_V,ISTL_V> opa(native(m));
   Dune::SeqILU0<ISTL_M,ISTL_V,ISTL_V> ilu0(native(m),1e-2);
 
@@ -240,7 +241,7 @@ int main(int argc, char** argv)
               << "g = " << g << std::endl;
 
     Dune::FieldVector<double,2> L(1); L[0] = szX;
-    Dune::array<int,2> N(Dune::fill_array<int,2>(1)); N[0] = szX;
+    std::array<int,2> N(Dune::filledArray<2,int>(1)); N[0] = szX;
     Dune::YaspGrid<2> grid(L,N);
     grid.globalRefine(level);
 
