@@ -3,7 +3,9 @@
 #endif
 
 #include <iostream>
+#include <cassert>
 
+#include <dune/common/filledarray.hh>
 #include <dune/common/math.hh>
 #include <dune/common/parallel/mpihelper.hh>
 
@@ -12,6 +14,11 @@
 #include <dune/pdelab/common/function.hh>
 #include <dune/pdelab/common/vtkexport.hh>
 
+#include <dune/pdelab/backend/istl.hh>
+#include <dune/pdelab/finiteelementmap/qkfem.hh>
+#include <dune/pdelab/gridfunctionspace/gridfunctionspace.hh>
+#include <dune/pdelab/function/discretegridviewfunction.hh>
+
 // an analytic scalar function
 template<typename T>
 class F : public Dune::PDELab::FunctionInterface<
@@ -180,6 +187,73 @@ void testfunctiontree (const GV& gv)
   vtkwriter.write("multi",Dune::VTK::ascii);
 }
 
+template<int k, class GV>
+void testgridviewfunction (const GV& gv)
+{
+    enum { dim = GV::dimension };
+    using FEM = Dune::PDELab::QkLocalFiniteElementMap<GV,float,double,k>;
+    FEM fem(gv);
+    // make a grid function space
+    using GFS = Dune::PDELab::GridFunctionSpace<GV,FEM>;
+    GFS gfs(gv,fem);
+    // make vector
+    using Vector = Dune::PDELab::Backend::Vector<GFS, double>;
+    Vector x(gfs);
+    // make functions
+    typedef Dune::PDELab::DiscreteGridViewFunction<GFS,Vector> DiscreteFunction;
+    DiscreteFunction dgvf(gfs,x);
+    // interpolate linear function
+    using Domain = Dune::FieldVector<typename GV::ctype, GV::dimension>;
+    using std::pow;
+    auto f = [](const Domain& x) {return pow(x[0],k);};
+    Dune::PDELab::interpolate(f,gfs,x);
+    // make local functions
+    auto localf = localFunction(dgvf);
+    // iterate grid and evaluate local function
+    static const int maxDiffOrder = 1;
+    std::cout << "max diff order: " << maxDiffOrder << std::endl;
+    std::cout << "checking for:\n";
+    std::cout << "\tevaluate\n";
+    if (maxDiffOrder >= 1)
+        std::cout << "\tjacobian\n";
+    if (maxDiffOrder >= 2)
+        std::cout << "\thessian\n";
+    if (maxDiffOrder >= 3)
+        std::cout << "\tdiff(3)\n";
+    for (auto it=gv.template begin<0>(); it!=gv.template end<0>(); ++it)
+    {
+        localf.bind(*it);
+        Dune::FieldVector<double,1> value;
+        Dune::FieldMatrix<double,1,dim> jacobian;
+        Dune::FieldMatrix<double,dim,dim> hessian;
+        Dune::FieldVector<double,dim> pos(0.0);
+        auto gpos = it->geometry().global(pos);
+        value = localf(pos);
+        assert(std::abs(value - pow(gpos[0],k)) < 1e-6);
+        if (maxDiffOrder >= 1) {
+            jacobian = derivative(localf)(pos);
+            assert(std::abs(jacobian[0][0] - k*pow(gpos[0],k-1)) < 1e-6);
+            assert(std::abs(jacobian[0][1]) < 1e-6);
+        }
+/* The following block is currently disabled as the tested QkLocalFiniteElementMap
+ * does not implement it and the maxDiffOrder based magic to not have these trigger
+ * compile errors had to be removed because of upstream changes in dune-localfunctions.
+        if (maxDiffOrder >= 2) {
+            hessian = derivative(derivative(localf))(pos);
+            assert(std::abs(hessian[0][0] - k*(k-1)*pow(gpos[0],k-2)) < 1e-6);
+            assert(std::abs(hessian[0][1]) < 1e-6);
+            assert(std::abs(hessian[1][1]) < 1e-6);
+            assert(std::abs(hessian[1][1]) < 1e-6);
+        }
+        if (maxDiffOrder >= 3)
+            derivative(
+                derivative(
+                    derivative(localf)));
+*/
+        localf.unbind();
+    }
+}
+
 int main(int argc, char** argv)
 {
   try{
@@ -202,7 +276,7 @@ int main(int argc, char** argv)
 
     // need a grid in order to test grid functions
     Dune::FieldVector<double,2> L(1.0);
-    Dune::array<int,2> N(Dune::fill_array<int,2>(1));
+    std::array<int,2> N(Dune::filledArray<2,int>(1));
     Dune::YaspGrid<2> grid(L,N);
     grid.globalRefine(6);
 
@@ -215,6 +289,10 @@ int main(int argc, char** argv)
     testvtkexport(grid.leafGridView(),F<Dune::YaspGrid<2>::ctype>());
     testfunctiontree(grid.leafGridView());
 
+    testgridviewfunction<1>(grid.leafGridView());
+    testgridviewfunction<2>(grid.leafGridView());
+    // testgridviewfunction<3>(grid.leafGridView());
+
     // test passed
     return 0;
 
