@@ -7,6 +7,7 @@
 
 #include <iostream>
 
+#include <dune/common/filledarray.hh>
 #include <dune/common/parallel/mpihelper.hh>
 
 #include <dune/grid/yaspgrid.hh>
@@ -27,8 +28,7 @@ struct test<2> {
   static void testleafgridfunction(const GV& gv)
   {
     // instantiate finite element maps
-    Dune::GeometryType gt;
-    gt.makeCube(2);
+    auto gt = Dune::GeometryTypes::quadrilateral;
     typedef Dune::PDELab::P0LocalFiniteElementMap<float,double,GV::dimension> P0FEM;
     P0FEM p0fem(gt);
     typedef Dune::PDELab::QkLocalFiniteElementMap<GV,float,double,1> Q12DFEM;
@@ -44,31 +44,31 @@ struct test<2> {
     typedef Dune::PDELab::GridFunctionSpace<GV,Q22DFEM> GFS2;
     GFS2 gfs2(gv,q22dfem);
     typedef Dune::PDELab::GridFunctionSpace<GV,Q22DFEM,Dune::PDELab::NoConstraints,
-      Dune::PDELab::istl::VectorBackend<> > GFS3;
+      Dune::PDELab::ISTL::VectorBackend<> > GFS3;
     GFS3 gfs3(gv,q22dfem);
 
     // test power
-    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,2,Dune::PDELab::istl::VectorBackend<> > PGFS2;
+    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,2,Dune::PDELab::ISTL::VectorBackend<> > PGFS2;
     PGFS2 pgfs2(gfs2,gfs2);
-    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,3,Dune::PDELab::istl::VectorBackend<> > PGFS3;
+    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,3,Dune::PDELab::ISTL::VectorBackend<> > PGFS3;
     PGFS3 pgfs3(gfs2,gfs2,gfs2);
-    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,4,Dune::PDELab::istl::VectorBackend<> > PGFS4;
+    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,4,Dune::PDELab::ISTL::VectorBackend<> > PGFS4;
     PGFS4 pgfs4(gfs2,gfs2,gfs2,gfs2);
-    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,5,Dune::PDELab::istl::VectorBackend<> > PGFS5;
+    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,5,Dune::PDELab::ISTL::VectorBackend<> > PGFS5;
     PGFS5 pgfs5(gfs2,gfs2,gfs2,gfs2,gfs2);
-    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,6,Dune::PDELab::istl::VectorBackend<> > PGFS6;
+    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,6,Dune::PDELab::ISTL::VectorBackend<> > PGFS6;
     PGFS6 pgfs6(gfs2,gfs2,gfs2,gfs2,gfs2,gfs2);
-    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,7,Dune::PDELab::istl::VectorBackend<> > PGFS7;
+    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,7,Dune::PDELab::ISTL::VectorBackend<> > PGFS7;
     PGFS7 pgfs7(gfs2,gfs2,gfs2,gfs2,gfs2,gfs2,gfs2);
-    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,8,Dune::PDELab::istl::VectorBackend<> > PGFS8;
+    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,8,Dune::PDELab::ISTL::VectorBackend<> > PGFS8;
     PGFS8 pgfs8(gfs2,gfs2,gfs2,gfs2,gfs2,gfs2,gfs2,gfs2);
-    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,9,Dune::PDELab::istl::VectorBackend<> > PGFS9;
+    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,9,Dune::PDELab::ISTL::VectorBackend<> > PGFS9;
     PGFS9 pgfs9(gfs2,gfs2,gfs2,gfs2,gfs2,gfs2,gfs2,gfs2,gfs2);
-    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,10,Dune::PDELab::istl::VectorBackend<> > PGFS10;
+    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,10,Dune::PDELab::ISTL::VectorBackend<> > PGFS10;
     PGFS10 pgfs10(gfs2,gfs2,gfs2,gfs2,gfs2,gfs2,gfs2,gfs2,gfs2,gfs2);
-    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,17,Dune::PDELab::istl::VectorBackend<> > PGFS17;
+    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,17,Dune::PDELab::ISTL::VectorBackend<> > PGFS17;
     PGFS17 pgfs17(gfs2);
-    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,17,Dune::PDELab::istl::VectorBackend<>,
+    typedef Dune::PDELab::PowerGridFunctionSpace<GFS2,17,Dune::PDELab::ISTL::VectorBackend<>,
         Dune::PDELab:: EntityBlockedOrderingTag> PGFS17B;
     PGFS17B pgfs17b(gfs2);
 
@@ -86,28 +86,28 @@ struct test<2> {
     }
 
     // test composite
-    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::istl::VectorBackend<>,
+    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::ISTL::VectorBackend<>,
         Dune::PDELab::LexicographicOrderingTag,GFS1,PGFS2> CGFS2;
     CGFS2 cgfs2(gfs1,pgfs2);
-    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::istl::VectorBackend<>,
+    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::ISTL::VectorBackend<>,
         Dune::PDELab::LexicographicOrderingTag,GFS1,PGFS2,CGFS2> CGFS3;
     CGFS3 cgfs3(gfs1,pgfs2,cgfs2);
-    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::istl::VectorBackend<>,
+    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::ISTL::VectorBackend<>,
         Dune::PDELab::LexicographicOrderingTag,GFS1,PGFS2,CGFS2,CGFS3> CGFS4;
     CGFS4 cgfs4(gfs1,pgfs2,cgfs2,cgfs3);
-    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::istl::VectorBackend<>,
+    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::ISTL::VectorBackend<>,
         Dune::PDELab::LexicographicOrderingTag,GFS1,PGFS2,CGFS2,CGFS3,CGFS4> CGFS5;
     CGFS5 cgfs5(gfs1,pgfs2,cgfs2,cgfs3,cgfs4);
-    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::istl::VectorBackend<>,
+    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::ISTL::VectorBackend<>,
         Dune::PDELab::LexicographicOrderingTag,GFS1,PGFS2,CGFS2,CGFS3,CGFS4,CGFS5> CGFS6;
     CGFS6 cgfs6(gfs1,pgfs2,cgfs2,cgfs3,cgfs4,cgfs5);
-    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::istl::VectorBackend<>,
+    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::ISTL::VectorBackend<>,
         Dune::PDELab::LexicographicOrderingTag,GFS1,PGFS2,CGFS2,CGFS3,CGFS4,CGFS5,CGFS6> CGFS7;
     CGFS7 cgfs7(gfs1,pgfs2,cgfs2,cgfs3,cgfs4,cgfs5,cgfs6);
-    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::istl::VectorBackend<>,
+    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::ISTL::VectorBackend<>,
         Dune::PDELab::LexicographicOrderingTag,GFS1,PGFS2,CGFS2,CGFS3,CGFS4,CGFS5,CGFS6,CGFS7> CGFS8;
     CGFS8 cgfs8(gfs1,pgfs2,cgfs2,cgfs3,cgfs4,cgfs5,cgfs6,cgfs7);
-    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::istl::VectorBackend<>,
+    typedef Dune::PDELab::CompositeGridFunctionSpace<Dune::PDELab::ISTL::VectorBackend<>,
         Dune::PDELab::LexicographicOrderingTag,GFS1,PGFS2,CGFS2,CGFS3,CGFS4,CGFS5,CGFS6,CGFS7,CGFS8> CGFS9;
     CGFS9 cgfs9(gfs1,pgfs2,cgfs2,cgfs3,cgfs4,cgfs5,cgfs6,cgfs7,cgfs8);
   }
@@ -119,8 +119,7 @@ struct test<3> {
   static void testleafgridfunction(const GV& gv)
   {
     // instantiate finite element maps
-    Dune::GeometryType gt;
-    gt.makeCube(3);
+    auto gt = Dune::GeometryTypes::hexahedron;
     typedef Dune::PDELab::P0LocalFiniteElementMap<float,double,GV::dimension> P0FEM;
     P0FEM p0fem(gt);
     typedef Dune::PDELab::PkLocalFiniteElementMap<GV,float,double,1> P1FEM;
@@ -157,7 +156,7 @@ int main(int argc, char** argv)
       std::cout << "2D tests" << std::endl;
       // need a grid in order to test grid functions
       Dune::FieldVector<double,2> L(1.0);
-      Dune::array<int,2> N(Dune::fill_array<int,2>(1));
+      std::array<int,2> N(Dune::filledArray<2,int>(1));
       Dune::YaspGrid<2> grid(L,N);
       grid.globalRefine(1);
 
@@ -169,7 +168,7 @@ int main(int argc, char** argv)
       std::cout << "3D tests" << std::endl;
       // need a grid in order to test grid functions
       Dune::FieldVector<double,3> L(1.0);
-      Dune::array<int,3> N(Dune::fill_array<int,3>(1));
+      std::array<int,3> N(Dune::filledArray<3,int>(1));
       Dune::YaspGrid<3> grid(L,N);
       grid.globalRefine(1);
 
