@@ -9,6 +9,7 @@
 #include <memory>
 
 #include <dune/common/exceptions.hh>
+#include <dune/common/filledarray.hh>
 #include <dune/common/fvector.hh>
 #include <dune/common/parallel/mpihelper.hh>
 
@@ -78,8 +79,7 @@ struct test<2,true> {
   static void testleafgridfunction(const GV& gv)
   {
     // instantiate finite element maps
-    Dune::GeometryType gt;
-    gt.makeCube(2);
+    auto gt = Dune::GeometryTypes::quadrilateral;
     typedef Dune::PDELab::P0LocalFiniteElementMap<float,double,GV::dimension> P0FEM;
     P0FEM p0fem(gt);
     typedef Dune::PDELab::QkLocalFiniteElementMap<GV,float,double,1> Q12DFEM;
@@ -93,7 +93,7 @@ struct test<2,true> {
 
     typedef Dune::PDELab::NoConstraints CON;
 
-    typedef Dune::PDELab::istl::VectorBackend<> VBE;
+    typedef Dune::PDELab::ISTL::VectorBackend<> VBE;
 
     // make a grid function space
     typedef Dune::PDELab::GridFunctionSpace<GV,P0FEM,CON,VBE> P0GFS;
@@ -116,7 +116,7 @@ struct test<2,true> {
 
     P1GFS p1gfs(gfs1,gfs1,gfs1,VBE(),{{1,1,1}});
 
-    typedef Dune::PDELab::istl::VectorBackend<Dune::PDELab::istl::Blocking::fixed,6> NVBE;
+    typedef Dune::PDELab::ISTL::VectorBackend<Dune::PDELab::ISTL::Blocking::fixed> NVBE;
 
     typedef Dune::PDELab::PowerGridFunctionSpace<P1GFS,2,NVBE,Dune::PDELab::InterleavedOrderingTag> PGFS;
     std::vector<std::size_t> p_gfs_block_sizes(2);
@@ -168,7 +168,7 @@ struct test<2,false> {
 
     typedef Dune::PDELab::NoConstraints CON;
 
-    typedef Dune::PDELab::istl::VectorBackend<> VBE;
+    typedef Dune::PDELab::ISTL::VectorBackend<> VBE;
 
     // make a grid function space
     typedef Dune::PDELab::GridFunctionSpace<GV,MonomFEM,CON,VBE> GFS3;
@@ -183,8 +183,7 @@ struct test<3,true> {
   static void testleafgridfunction(const GV& gv)
   {
     // instantiate finite element maps
-    Dune::GeometryType gt;
-    gt.makeCube(3);
+    auto gt = Dune::GeometryTypes::hexahedron;
     typedef Dune::PDELab::P0LocalFiniteElementMap<float,double,GV::dimension> P0FEM;
     P0FEM p0fem(gt);
     typedef Dune::PDELab::QkLocalFiniteElementMap<GV,float,double,1> Q1FEM;
@@ -237,7 +236,7 @@ int main(int argc, char** argv)
       typedef Dune::ALUGrid<2,2,Dune::simplex,Dune::conforming> Grid;
       Dune::FieldVector<double,2> l(0.0);
       Dune::FieldVector<double,2> u(1.0);
-      Dune::array<unsigned int,2> N = {{1,1}};
+      std::array<unsigned int,2> N = {{1,1}};
       std::shared_ptr<Grid> grid = Dune::StructuredGridFactory<Grid>::createSimplexGrid(l,u,N);
       grid->globalRefine(1);
 
@@ -250,7 +249,7 @@ int main(int argc, char** argv)
       std::cout << "3D tests" << std::endl;
       // need a grid in order to test grid functions
       Dune::FieldVector<double,3> L(1.0);
-      Dune::array<int,3> N(Dune::fill_array<int,3>(1));
+      std::array<int,3> N(Dune::filledArray<3,int>(1));
       Dune::YaspGrid<3> grid(L,N);
       grid.globalRefine(1);
 
