@@ -25,17 +25,19 @@ int main(int argc, char **argv)
     int overlap = 1;
 
     // Building a non-symmetric grid to make sure coordinate transformations work correctly
-    Dune::array<std::vector<NumberType>,dim> coords;
+    std::array<std::vector<NumberType>,dim> coords;
     for (int i=0; i<2; i++)
     {
-      coords[i].resize(7);
+      coords[i].resize(9);
       coords[i][0] = 0.0;
-      coords[i][1] = 0.25;
-      coords[i][2] = 0.375;
-      coords[i][3] = 0.5;
-      coords[i][4] = 0.8;
-      coords[i][5] = 0.9;
-      coords[i][6] = 1.0;
+      coords[i][1] = 0.125;
+      coords[i][2] = 0.25;
+      coords[i][3] = 0.375;
+      coords[i][4] = 0.5;
+      coords[i][5] = 0.6;
+      coords[i][6] = 0.8;
+      coords[i][7] = 0.9;
+      coords[i][8] = 1.0;
     }
     coords[2].resize(3);
     coords[2][0] = 0.0;
