@@ -10,7 +10,9 @@
 #include <map>
 #include <string>
 
+#include <dune/common/filledarray.hh>
 #include <dune/common/parallel/mpihelper.hh>
+#include <dune/common/std/make_array.hh>
 #include <dune/grid/yaspgrid.hh>
 #include <dune/grid/utility/structuredgridfactory.hh>
 
@@ -152,7 +154,7 @@ void poisson (const GV& gv, const FEM& fem, std::string filename, int q)
 
   // make function space
   typedef Dune::PDELab::GridFunctionSpace<GV,FEM,CON,
-    Dune::PDELab::istl::VectorBackend<> > GFS;
+    Dune::PDELab::ISTL::VectorBackend<> > GFS;
   GFS gfs(gv,fem);
   gfs.name("solution");
 
@@ -175,7 +177,7 @@ void poisson (const GV& gv, const FEM& fem, std::string filename, int q)
   typedef Dune::PDELab::ISTLMatrixBackend MBE;
   MBE mbe;
 #else
-  typedef Dune::PDELab::istl::BCRSMatrixBackend<> MBE;
+  typedef Dune::PDELab::ISTL::BCRSMatrixBackend<> MBE;
   MBE mbe(27); // 27 is too large / correct for all test cases, so should work fine
 #endif
 
@@ -235,11 +237,11 @@ void poisson (const GV& gv, const FEM& fem, std::string filename, int q)
   gridoperator.residual(x0,r);
 
   // make ISTL solver
-  Dune::MatrixAdapter<typename M::BaseT,typename DV::BaseT,typename RV::BaseT> opa(native(m));
+  Dune::MatrixAdapter<typename M::Container,typename DV::Container,typename RV::Container> opa(native(m));
   //ISTLOnTheFlyOperator opb(gridoperator);
-  Dune::SeqSSOR<typename M::BaseT,typename DV::BaseT,typename RV::BaseT> ssor(native(m),1,1.0);
-  Dune::SeqILU0<typename M::BaseT,typename DV::BaseT,typename RV::BaseT> ilu0(native(m),1.0);
-  Dune::Richardson<typename DV::BaseT,typename RV::BaseT> richardson(1.0);
+  Dune::SeqSSOR<typename M::Container,typename DV::Container,typename RV::Container> ssor(native(m),1,1.0);
+  Dune::SeqILU0<typename M::Container,typename DV::Container,typename RV::Container> ilu0(native(m),1.0);
+  Dune::Richardson<typename DV::Container,typename RV::Container> richardson(1.0);
 
 //   typedef Dune::Amg::CoarsenCriterion<Dune::Amg::SymmetricCriterion<M,
 //     Dune::Amg::FirstDiagonal> > Criterion;
@@ -253,9 +255,9 @@ void poisson (const GV& gv, const FEM& fem, std::string filename, int q)
 //   typedef Dune::Amg::AMG<Dune::MatrixAdapter<M,V,V>,V,Smoother> AMG;
 //   AMG amg(opa,criterion,smootherArgs,1,1);
 
-  Dune::CGSolver<typename DV::BaseT> solvera(opa,ilu0,1E-10,5000,2);
+  Dune::CGSolver<typename DV::Container> solvera(opa,ilu0,1E-10,5000,2);
   // FIXME: Use ISTLOnTheFlyOperator in the second solver again
-  Dune::CGSolver<typename DV::BaseT> solverb(opa,richardson,1E-10,5000,2);
+  Dune::CGSolver<typename DV::Container> solverb(opa,richardson,1E-10,5000,2);
   Dune::InverseOperatorResult stat;
 
   // solve the jacobian system
@@ -284,7 +286,7 @@ int main(int argc, char** argv)
     {
       // make grid
       Dune::FieldVector<double,2> L(1.0);
-      Dune::array<int,2> N(Dune::fill_array<int,2>(1));
+      std::array<int,2> N(Dune::filledArray<2,int>(1));
       Dune::YaspGrid<2> grid(L,N);
       grid.globalRefine(3);
 
@@ -305,7 +307,7 @@ int main(int argc, char** argv)
     {
       // make grid
       Dune::FieldVector<double,2> L(1.0);
-      Dune::array<int,2> N(Dune::fill_array<int,2>(1));
+      std::array<int,2> N(Dune::filledArray<2,int>(1));
       Dune::YaspGrid<2> grid(L,N);
       grid.globalRefine(3);
 
@@ -326,7 +328,7 @@ int main(int argc, char** argv)
     {
       // make grid
       Dune::FieldVector<double,3> L(1.0);
-      Dune::array<int,3> N(Dune::fill_array<int,3>(1));
+      std::array<int,3> N(Dune::filledArray<3,int>(1));
       Dune::YaspGrid<3> grid(L,N);
       grid.globalRefine(3);
 
@@ -347,7 +349,7 @@ int main(int argc, char** argv)
     {
       // make grid
       Dune::FieldVector<double,3> L(1.0);
-      Dune::array<int,3> N(Dune::fill_array<int,3>(1));
+      std::array<int,3> N(Dune::filledArray<3,int>(1));
       Dune::YaspGrid<3> grid(L,N);
       grid.globalRefine(3);
 
@@ -412,7 +414,7 @@ int main(int argc, char** argv)
 #if HAVE_DUNE_ALUGRID
     {
       using ALUType = Dune::ALUGrid<2, 2, Dune::simplex, Dune::nonconforming>;
-      auto alugrid = Dune::StructuredGridFactory<ALUType>::createSimplexGrid(Dune::FieldVector<ALUType::ctype, 2>(0.0), Dune::FieldVector<ALUType::ctype, 2>(1.0), Dune::make_array(1u, 1u));
+      auto alugrid = Dune::StructuredGridFactory<ALUType>::createSimplexGrid(Dune::FieldVector<ALUType::ctype, 2>(0.0), Dune::FieldVector<ALUType::ctype, 2>(1.0), Dune::Std::make_array(1u, 1u));
       alugrid->globalRefine(4);
 
       // get view
