@@ -28,7 +28,7 @@ void test(GV gv, const FEM& fem, const BaseFEM& baseFEM)
   typename GV::template Codim<0>::Iterator it = gv.template begin<0>();
   const typename FEM::Traits::FiniteElement& fe = fem.find(*it);
   const typename BaseFEM::Traits::FiniteElement& bfe = baseFEM.find(*it);
-  static_assert((Dune::is_same<typename FEM::Traits::FiniteElement,typename BaseFEM::Traits::FiniteElement>::value),
+  static_assert((std::is_same<typename FEM::Traits::FiniteElement,typename BaseFEM::Traits::FiniteElement>::value),
                 "Implementation error in RaviartThomasLocalFiniteElementMap: picked wrong base FEM");
   if (fe.localBasis().size() != bfe.localBasis().size())
     DUNE_THROW(Dune::InvalidStateException,"finite elements should be of same size");
@@ -45,8 +45,7 @@ int main(int argc, char** argv)
     {
       // make grid
       Dune::FieldVector<double,2> L(1.0);
-      Dune::array<int,2> N(Dune::fill_array<int,2>(1));
-      Dune::YaspGrid<2> grid(L,N);
+      Dune::YaspGrid<2> grid(L,{{1,1}});
       grid.globalRefine(3);
 
       // get view
@@ -80,8 +79,7 @@ int main(int argc, char** argv)
     {
       // make grid
       Dune::FieldVector<double,3> L(1.0);
-      Dune::array<int,3> N(Dune::fill_array<int,3>(1));
-      Dune::YaspGrid<3> grid(L,N);
+      Dune::YaspGrid<3> grid(L,{{1,1,1}});
       grid.globalRefine(3);
 
       // get view
@@ -109,7 +107,8 @@ int main(int argc, char** argv)
 
     {
       using ALUType = Dune::ALUGrid<2, 2, Dune::simplex, Dune::nonconforming>;
-      auto alugrid = Dune::StructuredGridFactory<ALUType>::createSimplexGrid(Dune::FieldVector<ALUType::ctype, 2>(0.0), Dune::FieldVector<ALUType::ctype, 2>(1.0), Dune::make_array(1u, 1u));
+      auto N = std::array<unsigned int,2> {{1,1}};
+      auto alugrid = Dune::StructuredGridFactory<ALUType>::createSimplexGrid(Dune::FieldVector<ALUType::ctype, 2>(0.0), Dune::FieldVector<ALUType::ctype, 2>(1.0), N);
       alugrid->globalRefine(4);
 
       auto gv = alugrid->leafGridView();
